@@ -109,12 +109,14 @@ static int init_pass(CSOUND *csound, INSDS *ip) {
     csoundLockMutex(csound->init_pass_threadlock);
   csound->curip = ip;
   csound->ids = (OPDS *)ip;
-  while (error == 0 && (csound->ids = csound->ids->nxti) != NULL){
+  csound->mode = 1;
+  while (error == 0 && (csound->ids = csound->ids->nxti) != NULL) {
+    csound->op = csound->ids->optext->t.oentry->opname;
     if (UNLIKELY(csound->oparms->odebug))
-      csound->Message(csound, "init %s:\n",
-                      csound->ids->optext->t.oentry->opname);
+      csound->Message(csound, "init %s:\n", csound->op);
     error = (*csound->ids->iopadr)(csound, csound->ids);
   }
+  csound->mode = 0;
   if(csound->oparms->realtime)
     csoundUnlockMutex(csound->init_pass_threadlock);
   return error;
@@ -129,13 +131,15 @@ static int reinit_pass(CSOUND *csound, INSDS *ip, OPDS *ids) {
   }
   csound->curip = ip;
   csound->ids = ids;
+  csound->mode = 1;
   while (error == 0 && (csound->ids = csound->ids->nxti) != NULL &&
          (csound->ids->iopadr != (SUBR) rireturn)){
-   if (UNLIKELY(csound->oparms->odebug))
-      csound->Message(csound, "reinit %s:\n",
-                      csound->ids->optext->t.oentry->opname);
+    csound->op = csound->ids->optext->t.oentry->opname;
+    if (UNLIKELY(csound->oparms->odebug))
+      csound->Message(csound, "reinit %s:\n", csound->op);
     error = (*csound->ids->iopadr)(csound, csound->ids);
   }
+  csound->mode = 0;
 
   ATOMIC_SET8(ip->actflg, 1);
   csound->reinitflag = ip->reinitflag = 0;
@@ -245,9 +249,12 @@ int init0(CSOUND *csound)
   ip->onedkr = csound->onedkr;
   ip->kicvt = csound->kicvt;
   csound->inerrcnt = 0;
+  csound->mode = 1;
   while ((csound->ids = csound->ids->nxti) != NULL) {
+    csound->op = csound->ids->optext->t.oentry->opname;
     (*csound->ids->iopadr)(csound, csound->ids);  /*   run all i-code     */
   }
+  csound->mode = 0;
   return csound->inerrcnt;                        /*   return errcnt      */
 }
 
@@ -346,6 +353,10 @@ int insert_event(CSOUND *csound, int insno, EVTBLK *newevtp)
                               "instr maxalloc"));
     return(0);
   }
+  /* If named ensure we have the fraction */
+  if (csound->engineState.instrtxtp[insno]->insname && newevtp->strarg)
+    newevtp->p[1] = named_instr_find(csound, newevtp->strarg);
+
   /* if find this insno, active, with indef (tie) & matching p1 */
   for (ip = tp->instance; ip != NULL; ip = ip->nxtinstance) {
     if (ip->actflg && ip->offtim < 0.0 && ip->p1.value == newevtp->p[1]) {
@@ -486,11 +497,16 @@ int insert_event(CSOUND *csound, int insno, EVTBLK *newevtp)
     start_time_kcycles = start_time_samps/csound->ksmps;
     ip->ksmps_offset = start_time_samps - start_time_kcycles*csound->ksmps;
     /* with no p3 or xtratim values, can't set the sample accur duration */
-    if (ip->p3.value > 0 && ip->xtratim == 0)
-      ip->no_end = csound->ksmps -
-        ((int)duration_samps+ip->ksmps_offset)%csound->ksmps;
+    if (ip->p3.value > 0 && ip->xtratim == 0 ){
+      int tmp = ((int)duration_samps+ip->ksmps_offset)%csound->ksmps;
+      if (tmp != 0)ip->no_end = csound->ksmps - tmp; else ip->no_end = 0;
+      //ip->no_end = (csound->ksmps -
+      //              ((int)duration_samps+ip->ksmps_offset)%csound->ksmps)%csound->ksmps;
     /* the ksmps_no_end field is initially 0, set to no_end in the last
        perf cycle */
+    //  printf("*** duration_samps %d ip->ksmps_offset %d csound->ksmps %d ==> %d\n",
+    //         (int)duration_samps, ip->ksmps_offset, csound->ksmps, ip->no_end);
+    }
     else ip->no_end = 0;
     ip->ksmps_no_end = 0;
   }
@@ -917,8 +933,9 @@ static void deact(CSOUND *csound, INSDS *ip)
       csound->Message(csound, Str("removed instance of instr %d\n"), ip->insno);
   }
   /* IV - Oct 24 2002: ip->prvact may be NULL, so need to check */
-  if (ip->prvact && (nxtp = ip->prvact->nxtact = ip->nxtact) != NULL)
+  if (ip->prvact && (nxtp = ip->prvact->nxtact = ip->nxtact) != NULL) {
     nxtp->prvact = ip->prvact;
+  }
   ip->actflg = 0;
   /* link into free instance chain */
   /* This also destroys ip->nxtact causing loops */
@@ -1134,6 +1151,8 @@ int csoundInitError(CSOUND *csound, const char *s, ...)
     va_end(args);
     csound->LongJmp(csound, 1);
   }
+  if (csound->mode != 1)
+    csound->Message(csound, Str("InitError in wrong mode %d\n"), csound->mode);
   /* IV - Oct 16 2002: check for subinstr and user opcode */
   ip = csound->ids->insdshead;
   if (ip->opcod_iobufs) {
@@ -1151,8 +1170,8 @@ int csoundInitError(CSOUND *csound, const char *s, ...)
                csound->ids->optext->t.linenum);
   }
   else
-    snprintf(buf, 512, Str("INIT ERROR in instr %d line %d: "), ip->insno,
-             csound->ids->optext->t.linenum);
+    snprintf(buf, 512, Str("INIT ERROR in instr %d (opcode %s) line %d: "),
+             ip->insno, csound->op, csound->ids->optext->t.linenum);
   va_start(args, s);
   csoundErrMsgV(csound, buf, s, args);
   va_end(args);
@@ -1167,6 +1186,8 @@ int csoundPerfError(CSOUND *csound, OPDS *h, const char *s, ...)
   char    buf[512];
   INSDS *ip = h->insdshead;
   TEXT t = h->optext->t;
+  if (csound->mode != 2)
+    csound->Message(csound, Str("PerfError in wrong mode %d\n"), csound->mode);
   if (ip->opcod_iobufs) {
     OPCODINFO *op = ((OPCOD_IOBUFS*) ip->opcod_iobufs)->opcode_info;
     /* find top level instrument instance */
@@ -1181,8 +1202,8 @@ int csoundPerfError(CSOUND *csound, OPDS *h, const char *s, ...)
                ip->insno, ip->insno, t.linenum);
   }
   else
-    snprintf(buf, 512, Str("PERF ERROR in instr %d line %d: "),
-             ip->insno, t.linenum);
+    snprintf(buf, 512, Str("PERF ERROR in instr %d (opcode %s) line %d: "),
+             ip->insno, csound->op, t.linenum);
   va_start(args, s);
   csoundErrMsgV(csound, buf, s, args);
   va_end(args);
@@ -1300,9 +1321,12 @@ int subinstrset_(CSOUND *csound, SUBINST *p, int instno)
   csound->curip = p->ip;        /* **** NEW *** */
   p->ip->init_done = 0;
   csound->ids = (OPDS *)p->ip;
+  csound->mode = 1;
   while ((csound->ids = csound->ids->nxti) != NULL) {
+    csound->op = csound->ids->optext->t.oentry->opname;
     (*csound->ids->iopadr)(csound, csound->ids);
   }
+  csound->mode = 0;
   p->ip->init_done = 1;
   /* copy length related parameters back to caller instr */
   saved_curip->xtratim = csound->curip->xtratim;
@@ -1451,7 +1475,7 @@ int useropcdset(CSOUND *csound, UOPCODE *p)
       lcurip->ekr = csound->esr / (MYFLT) local_ksmps;
       lcurip->onedkr = FL(1.0) / lcurip->ekr;
       lcurip->kicvt = (MYFLT) FMAXLEN /lcurip->ekr;
-      lcurip->kcounter *= ksmps_scale;
+      lcurip->kcounter = (CS_KCNT)*ksmps_scale;
     } else {
       lcurip->ksmps = CS_KSMPS;
       lcurip->kcounter = CS_KCNT;
@@ -1511,10 +1535,13 @@ int useropcdset(CSOUND *csound, UOPCODE *p)
     csound->curip = lcurip;
     csound->ids = (OPDS *) (lcurip->nxti);
     ATOMIC_SET(p->ip->init_done, 0);
+    csound->mode = 1;
     while (csound->ids != NULL) {
+      csound->op = csound->ids->optext->t.oentry->opname;
       (*csound->ids->iopadr)(csound, csound->ids);
       csound->ids = csound->ids->nxti;
     }
+    csound->mode = 0;
     ATOMIC_SET(p->ip->init_done, 1);
     /* copy length related parameters back to caller instr */
     parent_ip->relesing = lcurip->relesing;
@@ -1604,7 +1631,11 @@ int xoutset(CSOUND *csound, XOUT *p)
     void* in = (void*)p->args[i];
     void* out = (void*)bufs[i];
     tmp[i] = in;
-    current->varType->copyValue(csound, out, in);
+    // DO NOT COPY K or A or F vars
+    if (csoundGetTypeForArg(in) != &CS_VAR_TYPE_K &&
+        csoundGetTypeForArg(in) != &CS_VAR_TYPE_F &&
+        csoundGetTypeForArg(in) != &CS_VAR_TYPE_A)
+      current->varType->copyValue(csound, out, in);
     current = current->next;
   }
 
@@ -1690,9 +1721,13 @@ int nstrnumset_S(CSOUND *csound, NSTRNUM *p)
 
 int nstrstr(CSOUND *csound, NSTRSTR *p)
 {
-    char *ss = cs_inverse_hash_get(csound,
-                                   csound->engineState.instrumentNames,
-                                   (int)*p->num);
+    char *ss;
+    if (csound->engineState.instrumentNames) {
+      ss = cs_inverse_hash_get(csound,
+                               csound->engineState.instrumentNames,
+                               (int)*p->num);
+    }
+    else ss= "";
     mfree(csound,p->ans->data);
     p->ans->data = cs_strdup(csound, ss);
     p->ans->size = strlen(ss);
@@ -1808,6 +1843,7 @@ int subinstr(CSOUND *csound, SUBINST *p)
   /*  run each opcode  */
   if (csound->ksmps == ip->ksmps) {
     int error = 0;
+    ip->kcounter++;
     if ((CS_PDS = (OPDS *) (ip->nxtp)) != NULL) {
       CS_PDS->insdshead->pds = NULL;
       do {
@@ -1818,7 +1854,7 @@ int subinstr(CSOUND *csound, SUBINST *p)
         }
       } while (error == 0 && (CS_PDS = CS_PDS->nxtp));
     }
-    ip->kcounter++;
+
   }
   else {
     int i, n = csound->nspout, start = 0;
@@ -1844,6 +1880,7 @@ int subinstr(CSOUND *csound, SUBINST *p)
     }
 
     for (i=start; i < n; i+=incr, ip->spin+=incr, ip->spout+=incr) {
+      ip->kcounter++;
       if ((CS_PDS = (OPDS *) (ip->nxtp)) != NULL) {
         int error = 0;
         CS_PDS->insdshead->pds = NULL;
@@ -1859,7 +1896,6 @@ int subinstr(CSOUND *csound, SUBINST *p)
           }
         } while (error == 0 && (CS_PDS = CS_PDS->nxtp));
       }
-      ip->kcounter++;
     }
     ip->spout = (MYFLT*) p->saved_spout.auxp;
   }
@@ -1895,6 +1931,7 @@ int useropcd1(CSOUND *csound, UOPCODE *p)
   MYFLT** internal_ptrs = p->buf->iobufp_ptrs;
   MYFLT** external_ptrs = p->ar;
   int done;
+  
 
   done = ATOMIC_GET(p->ip->init_done);
   if (UNLIKELY(!done)) /* init not done, exit */
@@ -1922,6 +1959,7 @@ int useropcd1(CSOUND *csound, UOPCODE *p)
 
   if (this_instr->ksmps == 1) {           /* special case for local kr == sr */
     do {
+      this_instr->kcounter++; /*kcounter needs to be incremented BEFORE perf */
       /* copy inputs */
       current = inm->in_arg_pool->head;
       for (i = 0; i < inm->inchns; i++) {
@@ -2008,8 +2046,6 @@ int useropcd1(CSOUND *csound, UOPCODE *p)
         current = current->next;
       }
 
-
-      this_instr->kcounter++;
       this_instr->spout += csound->nchnls;
       this_instr->spin  += csound->nchnls;
     } while (++ofs < g_ksmps);
@@ -2031,6 +2067,7 @@ int useropcd1(CSOUND *csound, UOPCODE *p)
     if (UNLIKELY(early)) this_instr->ksmps_no_end = early % lksmps;
 
     do {
+      this_instr->kcounter++;
       /* copy a-sig inputs, accounting for offset */
       size_t asigSize = (this_instr->ksmps * sizeof(MYFLT));
       current = inm->in_arg_pool->head;
@@ -2122,7 +2159,7 @@ int useropcd1(CSOUND *csound, UOPCODE *p)
 
       this_instr->spout += csound->nchnls*lksmps;
       this_instr->spin  += csound->nchnls*lksmps;
-      this_instr->kcounter++;
+      
     } while ((ofs += this_instr->ksmps) < g_ksmps);
   }
 
@@ -2197,12 +2234,12 @@ int useropcd2(CSOUND *csound, UOPCODE *p)
 {
   OPDS    *saved_pds = CS_PDS;
   MYFLT   **tmp;
-  INSDS    *this_instr = p->ip;
   OPCODINFO   *inm;
   CS_VARIABLE* current;
   int i, done;
+  
 
-  inm = (OPCODINFO*) p->h.optext->t.oentry->useropinfo;
+  inm = (OPCODINFO*) p->h.optext->t.oentry->useropinfo; /* FIXME value not used */
   done = ATOMIC_GET(p->ip->init_done);
 
   if (UNLIKELY(!done)) /* init not done, exit */
@@ -2210,11 +2247,11 @@ int useropcd2(CSOUND *csound, UOPCODE *p)
 
   p->ip->spin = p->parent_ip->spin;
   p->ip->spout = p->parent_ip->spout;
+  p->ip->kcounter++;  /* kcount should be incremented BEFORE perf */
 
   if (UNLIKELY(!(CS_PDS = (OPDS*) (p->ip->nxtp))))
     goto endop; /* no perf code */
 
-
   /* IV - Nov 16 2002: update release flag */
   p->ip->relesing = p->parent_ip->relesing;
   tmp = p->buf->iobufp_ptrs;
@@ -2258,7 +2295,7 @@ int useropcd2(CSOUND *csound, UOPCODE *p)
   } while (error == 0 && p->ip != NULL
            && (CS_PDS = CS_PDS->nxtp));
   }
-  this_instr->kcounter++;
+  
 
   /* copy outputs */
   current = inm->out_arg_pool->head;
@@ -2689,8 +2726,8 @@ int csoundKillInstanceInternal(CSOUND *csound, MYFLT instr, char *instrName,
   int   insno;
 
   if (instrName) {
-    insno = named_instr_find(csound, instrName);
-    instr = (MYFLT) insno;
+    instr = named_instr_find(csound, instrName);
+    insno = (int) instr;
   } else insno = instr;
 
   if (UNLIKELY(insno < 1 || insno > (int) csound->engineState.maxinsno ||
