@@ -50,6 +50,7 @@ int     MIDIinsert(CSOUND *, int, MCHNBLK*, MEVENT*);
   void    remote_Cleanup(CSOUND *);
   char    **csoundGetSearchPathFromEnv(CSOUND *, const char *);
 void    openMIDIout(CSOUND *);
+void print_csound_version(CSOUND*);
 
 #ifdef HAVE_PTHREAD_SPIN_LOCK
 #define RT_SPIN_TRYLOCK { int trylock = CSOUND_SUCCESS; \
@@ -428,7 +429,11 @@ static void deactivate_all_notes(CSOUND *csound)
 
     while (ip != NULL) {
       INSDS *nxt = ip->nxtact;
+#ifdef BETA
+      printf("deativate: ip, nxt = %p , %p\n", ip, nxt);
+#endif
       xturnoff_now(csound, ip);
+      // should not be needed -- if (ip == nxt) break;
       ip = nxt;
     }
 }
@@ -451,6 +456,30 @@ static void delete_pending_rt_events(CSOUND *csound)
   csound->OrcTrigEvts = NULL;
 }
 
+void delete_selected_rt_events(CSOUND *csound, int instr)
+{
+  EVTNODE *ep = csound->OrcTrigEvts;
+  EVTNODE *last = NULL;
+  while (ep != NULL) {
+    EVTNODE *nxt = ep->nxt;
+    if (ep->evt.opcod=='i' && (int)(ep->evt.p[1]) == instr) {
+      // Found an event to cancel
+      if (ep->evt.strarg != NULL) {
+        // clearstring if necessary
+        csound->Free(csound,ep->evt.strarg);
+        ep->evt.strarg = NULL;
+      }
+      if (last) last->nxt = nxt; else csound->OrcTrigEvts = nxt;
+      /* push to stack of free event nodes */
+      ep->nxt = csound->freeEvtNodes;
+      csound->freeEvtNodes = ep;
+    }
+    else last = ep;
+    ep = nxt;
+  }
+  //csound->OrcTrigEvts = NULL;
+}
+
 static inline void cs_beep(CSOUND *csound)
 {
     csound->Message(csound, Str("%c\tbeep!\n"), '\a');
@@ -533,6 +562,7 @@ PUBLIC int csoundCleanup(CSOUND *csound)
       csound->Message(csound, Str("\n%d errors in performance\n"),
                       csound->perferrcnt);
       print_benchmark_info(csound, Str("end of performance"));
+      if (csound->print_version) print_csound_version(csound);
     }
     /* close line input (-L) */
     RTclose(csound);
@@ -745,12 +775,14 @@ static int process_score_event(CSOUND *csound, EVTBLK *evt, int rtEvt)
     return (evt->opcod == 'l' ? 3 : (evt->opcod == 's' ? 1 : 2));
   case 'q':
     if (csound->ISSTRCOD(evt->p[1]) && evt->strarg) {    /* IV - Oct 31 2002 */
-      if (UNLIKELY((insno = (int) named_instr_find(csound, evt->strarg)) == 0)) {
+      MYFLT n = named_instr_find(csound, evt->strarg);
+      if (UNLIKELY((insno = (int) n) == 0)) {
         printScoreError(csound, rtEvt,
                         Str(" - note deleted. instr %s undefined"),
                         evt->strarg);
         break;
       }
+      evt->p[1] = n;
       csound->Message(csound, Str("Setting instrument %s %s\n"),
                       evt->strarg, (evt->p[3] == 0 ? Str("off") : Str("on")));
       csound->engineState.instrtxtp[insno]->muted = (int16) evt->p[3];
@@ -773,12 +805,14 @@ static int process_score_event(CSOUND *csound, EVTBLK *evt, int rtEvt)
   case 'i':
   case 'd':
     if (csound->ISSTRCOD(evt->p[1]) && evt->strarg) {    /* IV - Oct 31 2002 */
-      if (UNLIKELY((insno = (int) named_instr_find(csound, evt->strarg)) == 0)) {
+      MYFLT n = named_instr_find(csound, evt->strarg);
+      if (UNLIKELY((insno = (int)n) == 0)) {
         printScoreError(csound, rtEvt,
                         Str(" - note deleted. instr %s undefined"),
                         evt->strarg);
         break;
       }
+      evt->p[1] = n;
       if (insno<0) {
         evt->p[1] = insno; insno = -insno;
       }
@@ -1351,8 +1385,10 @@ int insert_score_event_at_sample(CSOUND *csound, EVTBLK *evt, int64_t time_ofs)
       }
     }
     else if (evt->strarg != NULL && csound->ISSTRCOD(p[1])) {
-      i = (int) named_instr_find(csound, evt->strarg);
-      if (i<0) {p[1]=i; i= -i;}
+      MYFLT n = named_instr_find(csound, evt->strarg);
+      p[1] = n;
+      i =(int) n;
+      if (n<0) {i= -i;}
     }
     else
       i = (int) fabs((double) p[1]);
