@@ -41,6 +41,7 @@
 #include "OpcodeBase.hpp"
 #include "csdl.h"
 #include <fluidsynth.h>
+#include <fluidsynth/version.h>
 
 static std::vector<fluid_synth_t *> &fluidsynths_for_ids() {
     static std::vector<fluid_synth_t *> fluidsynths_for_ids_;
@@ -118,8 +119,14 @@ public:
       result =
           csound->InitError(csound, "%s", Str("error allocating fluid engine\n"));
     } else {
+#if (FLUIDSYNTH_VERSION_MAJOR >= 2 && FLUIDSYNTH_VERSION_MINOR >= 3)
+      // TODO: Change -1 to a configurable FX group?
+      fluid_synth_chorus_on(fluidSynth, -1, chorusEnabled);
+      fluid_synth_reverb_on(fluidSynth, -1, reverbEnabled);
+#else
       fluid_synth_set_chorus_on(fluidSynth, chorusEnabled);
       fluid_synth_set_reverb_on(fluidSynth, reverbEnabled);
+#endif
       log(csound, "Created fluidEngine 0x%p with sampling rate = %f, "
                   "chorus %s, reverb %s, channels %d, voices %d.\n",
           fluidSynth, (double)csound->GetSr(csound),
@@ -209,7 +216,7 @@ public:
       OPARMS oparms;
       csound->GetOParms(csound, &oparms);
       if (oparms.msglevel & 0x7)
-        while (fluidPreset = fluid_sfont_iteration_next(fluidSoundfont))
+        while ((fluidPreset = fluid_sfont_iteration_next(fluidSoundfont)))
         {
           log(csound, "SoundFont: %3d  Bank: %3d  Preset: %3d  %s\n",
               soundFontId, fluid_preset_get_banknum(fluidPreset),
@@ -261,7 +268,7 @@ public:
       OPARMS oparms;
       csound->GetOParms(csound, &oparms);
       if (oparms.msglevel & 0x7)
-        while (fluidPreset = fluid_sfont_iteration_next(fluidSoundfont))
+        while ((fluidPreset = fluid_sfont_iteration_next(fluidSoundfont)))
         {
             std::stringstream ss;
             ss << "Bank: " << fluid_preset_get_banknum(fluidPreset) <<
